@@ -96,6 +96,7 @@ ERRORS = {
     10200: 'Error in un-authentication request',
     10300: 'Subscription Failed (generic)',
     10301: 'Already Subscribed',
+    10305: 'Reached limit of open channels',
     10302: 'Unknown channel',
     10400: 'Subscription Failed (generic)',
     10401: 'Not subscribed',
@@ -158,7 +159,6 @@ class BfxWebsocket(GenericWebsocket):
         self.API_SECRET = API_SECRET
         self.manageOrderBooks = manageOrderBooks
         self.dead_man_switch = dead_man_switch
-        self.pendingOrders = {}
         self.orderBooks = {}
         self.ws_capacity = ws_capacity
         self.channel_filter = channel_filter
@@ -266,7 +266,7 @@ class BfxWebsocket(GenericWebsocket):
             socketId,
             ERRORS[data.get('code', 10000)],
             data.get("msg", ""))
-        self._emit('error', err_string)
+        self._emit(Exception(err_string))
 
     async def _system_auth_handler(self, socketId, data):
         if data.get('status') == 'FAILED':
@@ -315,6 +315,7 @@ class BfxWebsocket(GenericWebsocket):
         notificationText = nInfo[7]
         if notificationType == 'ERROR':
             # self._emit('error', notificationText)
+            await self._order_error_handler(data)
             self.logger.error(
                 "Notification ERROR: {}".format(notificationText))
         else:
@@ -328,6 +329,9 @@ class BfxWebsocket(GenericWebsocket):
     async def _order_closed_handler(self, data):
         await self.orderManager.confirm_order_closed(data)
 
+    async def _order_error_handler(self, data):
+        await self.orderManager.confirm_order_error(data)
+
     async def _order_update_handler(self, data):
         await self.orderManager.confirm_order_update(data)
 
